let dappaccount = {};

let { PrivateKey, PublicKey } = require("eosjs-ecc");
let helperaction = require("./common/helper");
const axios = require("axios").default;
let chaininfo = require("./common/chaininfo.json");
let sha256 = require("sha256");
let dappaccountauth = require('./dappmethods')
dappaccount.register_both = async (env, email, contact, otp) => {
  try {
    if (!chaininfo[env]) {
      throw new Error("Must provide environment correctly : kylin / main");
    }
    let prv_key = await PrivateKey.randomKey();
    prv_key = prv_key.toWif();
    const response_reg = await helperaction.reguser(
      env,
      email,
      contact,
      otp,
      prv_key
    );
    console.log("--res", response_reg);
    return {
      accname: response_reg.accname,
      key: prv_key,
    };
  } catch (err) {
    throw new Error(err);
  }
};

dappaccount.verifyemailreg = async (env, email, dappname) => {
  try {
    if (!chaininfo[env]) {
      throw new Error("Must provide environment correctly : kylin / main");
    }
    let resp = await axios.post(chaininfo[env].twofactregemail, {
      email: email.toLowerCase(),
      dappname: dappname
    });
    return resp.data;
  } catch (err) {
    throw new Error(err.response.data.message);
  }
};

dappaccount.verifyemailreset = async (env, email, dappname) => {
  try {
    if (!chaininfo[env]) {
      throw new Error("Must provide environment correctly : kylin / main");
    }
    let dappacc = await helperaction.converttovacc(email.toLowerCase());
    let resp = await axios.post(chaininfo[env].twofactlogin, {
      vaccount: dappacc,
      email: email.toLowerCase(),
      dappname: dappname
    });
    console.log("--", resp);
    return resp.data;
  } catch (err) {
    throw new Error(err.response.data.message);
  }
};
//dappaccount.verifyemailreset('kylin','rayarunima55@gmail.com')
dappaccount.recover = async (env, email, auth_code) => {
  try {
    if (!chaininfo[env]) {
      throw new Error("Must provide environment correctly : kylin / main");
    }
    let prv_key = await PrivateKey.randomKey();
    prv_key = prv_key.toWif();

    const response_reg = await helperaction.recoveruser(
      env,
      email.toLowerCase(),
      auth_code,
      prv_key
    );
    console.log(response_reg);
    let resp = await axios.get(
      `${chaininfo[env].removeauthinfo}/${response_reg.accname}`
    );
    return {
      accname: response_reg.accname,
      key: prv_key,
    };
  } catch (err) {
    throw new Error(err);
  }
};
//dappaccount.recover('kylin','rayarunima55@gmail.com','107881')
dappaccount.signtrx = async (env, contract, key, action, data = {}) => {
  try {
    if (!chaininfo[env]) {
      throw new Error("Must provide environment correctly : kylin / main");
    }
    const resp = await helperaction.signdappacc(
      env,
      contract,
      key,
      action,
      data
    );
    if (resp.public_key) {
      return resp;
    } else {
      return new Error("Error in signing trx");
    }
  } catch (err) {
    throw new Error(err);
  }
};

dappaccount.posttrx = async (env, contract, pubkey, signature, payload) => {
  try {
    if (!chaininfo[env]) {
      throw new Error("Must provide environment correctly : kylin / main");
    }
    const resp = await helperaction.postdappacc(
      env,
      contract,
      pubkey,
      signature,
      payload
    );
    if (resp.message) {
      return resp;
    }
  } catch (err) {
    throw new Error(err);
  }
};

dappaccount.pushtrx = async (env, contract, key, action, data) => {
  try {
    if (!chaininfo[env]) {
      throw new Error("Must provide environment correctly : kylin / main");
    }
    const resp = await helperaction.pushdappacc(
      env,
      contract,
      key,
      action,
      data
    );
    if (resp.message) {
      return resp;
    }
  } catch (err) {
    throw new Error(err);
  }
};

// dappaccount.pushtrx('kylin', 'vaccconuser1', '5JYaTw6ZRJHtWuwW3B1zcR78iiRNLEFtXA7pHXSJNp4BoMx1PT3', 'addsign', {
//   vaccount: 'teststakeac3',
//   //initial: "aray",
//   type: 'test14'
//   })

// dappaccount.pushtrx(
//   "kylin",
//   "vaccconuser1",
//   "5KQcqJRypZJy4ptBfGjWX6uMoFQm1wmJFEmyig8SBxRVupnFSSR",
//   "createpropos",
//   {
//     id: 4,
//     vaccount: "dap2vyogkjwj",
//     companyemail: "hackingpayload2@gmail.com",
//     users: [
//       {
//         username: "teststakeac3",
//         email: "rayarunima55@gmail.com",
//         is_signed: false,
//       },
//       {
//         username: "teststakeac2",
//         email: "rayarunima55@gmail.com",
//         is_signed: false,
//       },
//     ],
//     agreementdata: "Library document testing 4-new",
//     observers: [{
//       username: "teststakeac3",
//       email: "rayarunima55@gmail.com"
//     },]
//   }
// );

dappaccount.converttodappacc = async (email) => {
  try {
    const resp = await helperaction.converttovacc(email);
    let abc = sha256(email);
    console.log(abc.toUpperCase());
    console.log(resp);
    if (resp) {
      return resp;
    }
  } catch (err) {
    throw new Error(err);
  }
};
//dappaccount.converttodappacc('n775140@gmail.com')

////////temporary 2fa impl/////////////////

//1) dappsignup

//////////////////////////////
module.exports = {dappaccount,dappaccountauth};
